@@ -2,14 +2,10 @@ from dataclasses import dataclass
 from typing import Any, List
 import inspect
 import itertools
+import warnings
 
 import requests
 
-try:
-    import aiohttp
-except ImportError:
-    aiohttp = None
-
 from flask_discord_interactions.response import Response
 
 
@@ -313,6 +309,11 @@ class Context(ContextObject):
         if data is None:
             data = {}
 
+        # If this is a proxy (e.g. flask.current_app), get the current object
+        # https://flask.palletsprojects.com/en/2.0.x/reqcontext/#notes-on-proxies
+        if hasattr(app, "_get_current_object"):
+            app = app._get_current_object()
+
         result = cls(
             app = app,
             discord = discord,
@@ -335,7 +336,8 @@ class Context(ContextObject):
 
     @property
     def auth_headers(self):
-        return self.discord.auth_headers(self.app)
+        if self.discord:
+            return self.discord.auth_headers(self.app)
 
     def parse_custom_id(self):
         """
@@ -489,6 +491,9 @@ class Context(ContextObject):
 
         response = Response.from_return_value(response)
 
+        if not self.app or self.app.config["DONT_REGISTER_WITH_DISCORD"]:
+            return
+
         response = requests.patch(
             self.followup_url(message),
             json=response.dump_followup(),
@@ -506,6 +511,9 @@ class Context(ContextObject):
             The message to delete. If omitted, deletes the original message.
         """
 
+        if not self.app or self.app.config["DONT_REGISTER_WITH_DISCORD"]:
+            return
+
         response = requests.delete(
             self.followup_url(message),
             headers=self.auth_headers
@@ -522,6 +530,9 @@ class Context(ContextObject):
             The response to send as a followup message.
         """
 
+        if not self.app or self.app.config["DONT_REGISTER_WITH_DISCORD"]:
+            return
+
         response = Response.from_return_value(response)
 
         response = requests.post(
@@ -564,6 +575,9 @@ class Context(ContextObject):
 
         data = [permission.dump() for permission in permissions]
 
+        if self.app.config["DONT_REGISTER_WITH_DISCORD"]:
+            return
+
         response = requests.put(url, headers=self.auth_headers, json={
             "permissions": data
         })
@@ -580,18 +594,10 @@ class AsyncContext(Context):
     """
 
     def __post_init__(self):
-        if aiohttp == None:
-            raise ImportError(
-                "The aiohttp module is required for async usage of this "
-                "library")
+        if not self.app or self.app.config["DONT_REGISTER_WITH_DISCORD"]:
+            return
 
-        self.session = aiohttp.ClientSession(
-            headers=self.auth_headers,
-            raise_for_status=True,
-        )
-
-        if aiohttp is None:
-            raise ValueError("aiohttp is required to create async contexts")
+        self.session = self.app.discord_client_session
 
     async def edit(self, response, message="@original"):
         """
@@ -607,6 +613,9 @@ class AsyncContext(Context):
 
         response = Response.from_return_value(response)
 
+        if not self.app or self.app.config["DONT_REGISTER_WITH_DISCORD"]:
+            return
+
         await self.session.patch(
             self.followup_url(message), json=response.dump_followup()
         )
@@ -621,6 +630,9 @@ class AsyncContext(Context):
             The message to delete. If omitted, deletes the original message.
         """
 
+        if not self.app or self.app.config["DONT_REGISTER_WITH_DISCORD"]:
+            return
+
         await self.session.delete(self.followup_url(message))
 
     async def send(self, response):
@@ -635,6 +647,9 @@ class AsyncContext(Context):
 
         response = Response.from_return_value(response)
 
+        if not self.app or self.app.config["DONT_REGISTER_WITH_DISCORD"]:
+            return
+
         async with self.session.post(
             self.followup_url(),
             headers=self.auth_headers,
@@ -664,9 +679,27 @@ class AsyncContext(Context):
 
         data = [permission.dump() for permission in permissions]
 
+        if not self.app or self.app.config["DONT_REGISTER_WITH_DISCORD"]:
+            return
+
         await self.session.put(url, headers=self.auth_headers, json={
             "permissions": data
         })
 
     async def close(self):
-        await self.session.close()
+        """
+        Deprecated as of v1.0.2.
+
+        Previously, this closed the AsyncContext's aiohttp ClientSession that
+        was used to send followup messages. This is no longer necessary, as
+        this library now maintains a single ClientSession for the entire
+        application.
+        """
+
+        warnings.warn(
+            "Deprecated! AsyncContext.close is a no-op. "
+            "Since v1.0.2, only one aiohttp ClientSession is created "
+            "for all requests to Discord for the app. "
+            "Thus, there is no need to close the AsyncContext. ",
+            DeprecationWarning
+        )
